@@ -1,8 +1,8 @@
-# $Header: /usr/local/CVS/Perl-Metrics-Simple/lib/Perl/Metrics/Simple/Analysis/File.pm,v 1.11 2006/12/14 17:09:06 matisse Exp $
-# $Revision: 1.11 $
+# $Header: /usr/local/CVS/Perl-Metrics-Simple/lib/Perl/Metrics/Simple/Analysis/File.pm,v 1.12 2007/05/10 15:12:27 matisse Exp $
+# $Revision: 1.12 $
 # $Author: matisse $
 # $Source: /usr/local/CVS/Perl-Metrics-Simple/lib/Perl/Metrics/Simple/Analysis/File.pm,v $
-# $Date: 2006/12/14 17:09:06 $
+# $Date: 2007/05/10 15:12:27 $
 ###############################################################################
 
 package Perl::Metrics::Simple::Analysis::File;
@@ -16,7 +16,7 @@ use Perl::Metrics::Simple::Analysis;
 use PPI;
 use Readonly;
 
-our $VERSION = '0.031';
+our $VERSION = '0.032';
 
 Readonly::Scalar my $ALL_NEWLINES_REGEX => qr/ ( \n ) /xm;
 Readonly::Array our @LOGIC_OPERATORS    =>
@@ -122,6 +122,7 @@ sub get_node_length {
     eval {
         $node = _prune_comments_and_pod($node);
     };
+    return 0 if ( !defined $node);
     my $string = $node->content;
     return 0 if ( ! length $string );
     $string =~ s/ \s+ \n /\n/msxg;
@@ -169,16 +170,11 @@ sub measure_complexity {
     my $elem  = shift;
     
     my $complexity_count = 0;
-
-    eval {
-        $elem->prune('PPI::Token::Comment');
-        $elem->prune('PPI::Token::Pod');
-    };
-    if ( $EVAL_ERROR ) {
+    if ( $self->get_node_length($elem) == 0 ) {
         return $complexity_count;
     }
 
-    if ( length "$elem" ) {
+    if ( $elem ) {
         $complexity_count++;
     }
 
@@ -366,36 +362,58 @@ Returns the hashref generated by I<analyze_main> without re-analyzing document.
 
 =head2 measure_complexity
 
-Takes a B<PPI> element and measures the McCabe Complexity
-(aka Cyclomatic Complexity) of the code.  McCabe Complexity
-is basically a count of how many paths there are through the code.
-We use a simplified method for count this, which ignores things like
-the possibility that a 'use' statement with throw an exception.
+Takes a B<PPI> element and measures an approximation of the
+McCabe Complexity (aka Cyclomatic Complexity) of the code.
 
-The complexity count is 1
-for any non-comment/pod code plus 1 for each logic keyword or operator:
+McCabe Complexity is basically a count of how many paths there are
+through the code.
 
-Logic operators:
+We use a simplified method for counting this, which ignores things like
+the possibility that a 'use' statement could throw an exception.
+
+The actual measurement we for a chunk of code is 1 plus
+1 each logic keyword or operator:
+
+=head3 Logic operators:
 
  ! && || ||= &&= or and xor not ? <<= >>=
 
-Logic keywords:
+=head3 Logic keywords:
 
  for foreach goto if else elsif last next unless until while
 
-Example of  complexity 1:
+=head3 Examples of Complexity
+
+Here are a couple of examples of how we count complexity:
+
+Example of complexity count of 1:
 
-   # Only one  path through the code.
    use Foo;
    print "Hello world.\n";
    exit;
 
-Example of complexity 2:
+Example of complexity count of 2:
 
-   # There are two possible paths through this code:
-   if ( $a ) {
+   if ( $a ) {         # The "if" adds 1.
+       # do something
    }
 
+Example of complexity count of 6:
+
+    sub foo {                              # 1: for non-empty code
+       if ( @list ) {                      # 1: "if"
+           foreach my $x ( @list ) {       # 1: "foreach"
+               if ( ! $x ) {               # 2: 1 for "if" and 1 for "!"
+                   do_something($x);
+               }
+               else {                      # 1 for "else"
+                   do_something_else($x);
+               }
+           }
+       }
+       return;
+    }
+
 =head2 packages
 
 Arrayref of unique packages found in the file.
